#[non_exhaustive]pub struct SqliteConfig {
pub connection_string: Option<String>,
pub table: Option<String>,
pub key_field: Option<String>,
pub value_field: Option<String>,
pub root: Option<String>,
}Expand description
Config for Sqlite support.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_string: Option<String>Set the connection_string of the sqlite service.
This connection string is used to connect to the sqlite service.
The format of connect string resembles the url format of the sqlite client:
sqlite::memory:sqlite:data.dbsqlite://data.db
For more information, please visit https://docs.rs/sqlx/latest/sqlx/sqlite/struct.SqliteConnectOptions.html.
table: Option<String>Set the table name of the sqlite service to read/write.
key_field: Option<String>Set the key field name of the sqlite service to read/write.
Default to key if not specified.
value_field: Option<String>Set the value field name of the sqlite service to read/write.
Default to value if not specified.
root: Option<String>set the working directory, all operations will be performed under it.
default: “/”